#![allow(unused)]
use bevy::prelude::*;
use bevy_rapier2d::prelude::*;
use game::game_plugin;

mod game;

const METER: f32 = 120.;

#[derive(States, Debug, Clone, PartialEq, Eq, Hash, Default)]
enum AppState {
    #[default]
    MainMenu,
    InGame,
    GameOver,
}

#[derive(States, Debug, Clone, PartialEq, Eq, Hash, Default)]
enum PausedState {
    Paused,
    #[default]
    Running,
}

fn main() {
    App::new()
        .add_plugins(DefaultPlugins)
        .add_plugins(RapierPhysicsPlugin::<NoUserData>::pixels_per_meter(METER))
        .add_systems(Startup, setup_camera)
        .add_plugins(game_plugin)
        .init_state::<AppState>()
        .init_state::<PausedState>()
        .insert_state(AppState::InGame) // TODO dont
        .run();
}

fn setup_camera(mut commands: Commands) {
    commands.spawn(Camera2dBundle::default());
}
